selectortools.select_first_logical_tie_in_pitched_runs
======================================================

.. autofunction:: abjad.tools.selectortools.select_first_logical_tie_in_pitched_runs.select_first_logical_tie_in_pitched_runs
